@@ -1,3 +1,2 @@
 """ Python implementation of Paradox HD7X cameras."""
-
-from pypdxapi.camera.hd77 import ParadoxHD77
+from .hd77 import ParadoxHD77
