@@ -7,7 +7,7 @@ from pypdxapi.helpers import discover
 
 def test_parse_response():
     data = 'paradoxip!type=a&ip=b&name=c'
-    result = discover.parse_response(data)
+    result = discover._parse_response(data)
 
     assert result == {'type': 'a', 'ip': 'b', 'name': 'c'}
 
@@ -18,6 +18,6 @@ def test_parse_modules():
         {'type': 'a2', 'ip': 'b2', 'name': 'c2'},
         {'type': 'a1', 'ip': 'b1', 'name': 'c1'},
     ]
-    result = discover.parse_modules(data)
+    result = discover._remove_duplicates(data)
 
     assert len(result) == 2
